@@ -1,18 +1,18 @@
 package Test::Software::License;
 
-use v5.10;
+use 5.008009;
 use warnings;
 use strict;
 use Carp;
 
 use version;
-our $VERSION = '0.001003';
+our $VERSION = '0.001005';
 use English qw( -no_match_vars );    # Avoids reg-ex performance penalty
 local $OUTPUT_AUTOFLUSH = 1;
 
 use parent 0.225 qw(Exporter);
 
-use Data::Printer {caller_info => 1, colored => 1,};
+# use Data::Printer {caller_info => 1, colored => 1,};
 # use Software::LicenseUtils 0.103005;
 use Test::Software::LicenseUtils;
 use File::Slurp;
@@ -38,7 +38,6 @@ my $passed_a_test = FALSE;
 sub import {
 	my $self = shift;
 	my $pack = caller;
-
 	my $Test = Test::Builder->new;
 
 	$Test->exported_to($pack);
@@ -205,17 +204,15 @@ __END__
 
 Test::Software::License - just another xt for Software::License
 
-
 =head1 VERSION
 
-This document describes Test::Software::License version 0.001002
-
+This document describes Test::Software::License version 0.001005
 
 =head1 SYNOPSIS
 
 	use Test::More;
 	use Test::Requires {
-		'Test::Software::License' => 0.00,
+		'Test::Software::License' => 0.001,
 	};
 
 	all_software_license_ok();
@@ -279,6 +276,7 @@ it under the same terms as Perl itself.
 =head1 SEE ALSO
 
 L<Software::License>
+L<XT::Manager>
 
 =cut
 
